sqlobject.inheritance.tests.test_inheritance_tree module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_inheritance_tree module

class `sqlobject.inheritance.tests.test_inheritance_tree.` `Tree1`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `aprop`
  property `childName`
  `j` = tree1
  `q` = tree1
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'Tree2': <class 'sqlobject.inheritance.tests.test_inheritance_tree.Tree2'>, 'Tree3': <class 'sqlobject.inheritance.tests.test_inheritance_tree.Tree3'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree1`

    `table` = 'tree1'

class `sqlobject.inheritance.tests.test_inheritance_tree.` `Tree2`(**kw)

  Bases: `sqlobject.inheritance.tests.test_inheritance_tree.Tree1`

  property `aprop`
  property `bprop`
  property `childName`
  `j` = tree2
  `q` = tree2
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {'Tree4': <class 'sqlobject.inheritance.tests.test_inheritance_tree.Tree4'>, 'Tree5': <class 'sqlobject.inheritance.tests.test_inheritance_tree.Tree5'>}
    `childName` = 'Tree2'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree1`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree2`

    `table` = 'tree2'

class `sqlobject.inheritance.tests.test_inheritance_tree.` `Tree3`(**kw)

  Bases: `sqlobject.inheritance.tests.test_inheritance_tree.Tree1`

  property `aprop`
  property `childName`
  property `cprop`
  `j` = tree3
  `q` = tree3
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Tree3'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree1`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree3`

    `table` = 'tree3'

class `sqlobject.inheritance.tests.test_inheritance_tree.` `Tree4`(**kw)

  Bases: `sqlobject.inheritance.tests.test_inheritance_tree.Tree2`

  property `bprop`
  property `childName`
  property `dprop`
  `j` = tree4
  `q` = tree4
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Tree4'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree2`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree4`

    `table` = 'tree4'

class `sqlobject.inheritance.tests.test_inheritance_tree.` `Tree5`(**kw)

  Bases: `sqlobject.inheritance.tests.test_inheritance_tree.Tree2`

  property `bprop`
  property `childName`
  property `eprop`
  `j` = tree5
  `q` = tree5
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Tree5'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree2`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance_tree.Tree5`

    `table` = 'tree5'

`sqlobject.inheritance.tests.test_inheritance_tree.` `test_tree`()